.. _dev:

Development Guidelines
======================

Developers of the and related packages must follow the guidelines specified in
the `CTAO Developer Documentation
<http://cta-computing.gitlab-pages.cta-observatory.org/documentation/developer-documentation/>`_.

More details are given in the `Gammapy developer guidelines
<https://docs.gammapy.org/dev/development/index.html>`_.
